@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.32 2002/11/12 07:42:56 bazsi Exp $ */
+ * $Id: io.c,v 1.34 2003/01/20 15:35:37 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -201,8 +201,10 @@ int io_iter(struct io_backend *b)
                 gc_maybe(&b->super, 0);
                 res = poll(fds, nfds, timeout < 0 ? 60000 : timeout * 1000);
         }
-        else
+        else {
                 gc_maybe(&b->super, 1);
+        	res = poll(NULL, 0, timeout < 0 ? 60000 : timeout * 1000);
+        }
 
 	if (res < 0)
 		switch(errno)
@@ -1031,7 +1033,7 @@ struct address_info *sockaddr2address_info(size_t addr_len,
 		break;
 #endif
 	default:
-		werror("io.c: sockaddr2info(): Unsupported address family %i (addrlen=%i).\n", addr->sa_family, addr_len);
+		verbose("io.c: sockaddr2info(): Unsupported address family %i (addrlen=%i).\n", addr->sa_family, addr_len);
 		break;
 	}
 	return NULL;
